==> aide_0.10.orig.tar.gz: aide-0.10/include/db_sql.h <==
/* aide, Advanced Intrusion Detection Environment
 *
 * Copyright (C) 1999,2000,2001,2002 Rami Lehti, Pablo Virolainen
 * $Header: /cvsroot/aide/aide/include/db_sql.h,v 1.1.1.1 2003/01/16 10:37:34 rammer Exp $
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _DB_SQL_H_INCLUDED
#define _DB_SQL_H_INCLUDED


const static char* db_sql_types[] = {
   "text unique primary key",/* "name",   */
   "text", 	         /* "lname",   */
   "int", 	         /* "perm",    */
   "int", 	         /* "uid",     */
   "int", 	         /* "gid",     */
   "int", 	         /* "size",    */
   "text", 	         /* "atime",   */
   "text", 	         /* "ctime",   */
   "text", 	         /* "mtime",   */
   "int", 	         /* "inode",   */
   "int", 	         /* "bcount",  */
   "int", 	         /* "lcount",  */
   "text", 	         /* "md5",     */
   "text", 	         /* "sha1",    */
   "text", 	         /* "rmd160",  */
   "text", 	         /* "tiger",   */
   "text", 	         /* "crc32",   */
   "text", 	         /* "haval",   */
   "text", 	         /* "gost",    */
   "text", 	         /* "crc32b",  */
   "int",                /* "attr",    */
   "text",               /* "acl",     */
   "int",                /* "checkmask",     */
   "text" 	         /* "unknown"  */
};

int db_close_sql(void*);
db_line* db_readline_sql(int db);

#endif

==> aide_0.13.1.orig.tar.gz: aide-0.13.1/include/db_sql.h <==
/* aide, Advanced Intrusion Detection Environment
 *
 * Copyright (C) 1999,2000,2001,2002 Rami Lehti, Pablo Virolainen
 * $Header: /cvsroot/aide/aide/include/db_sql.h,v 1.4 2006/10/27 18:54:29 rvdb Exp $
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _DB_SQL_H_INCLUDED
#define _DB_SQL_H_INCLUDED


static __attribute__ ((used)) const char* db_sql_types[] = {
   "text unique primary key",/* "name",   */
   "text", 	         /* "lname",   */
   "int", 	         /* "perm",    */
   "int", 	         /* "uid",     */
   "int", 	         /* "gid",     */
   "bigint",         /* "size",    */
   "text", 	         /* "atime",   */
   "text", 	         /* "ctime",   */
   "text", 	         /* "mtime",   */
   "int", 	         /* "inode",   */
   "int", 	         /* "bcount",  */
   "int", 	         /* "lcount",  */
   "text", 	         /* "md5",     */
   "text", 	         /* "sha1",    */
   "text", 	         /* "rmd160",  */
   "text", 	         /* "tiger",   */
   "text", 	         /* "crc32",   */
   "text", 	         /* "haval",   */
   "text", 	         /* "gost",    */
   "text", 	         /* "crc32b",  */
   "int",                /* "attr",    */
   "text",               /* "acl",     */
   "int",                /* "checkmask",     */
   "text" 	         /* "unknown"  */
};

int db_close_sql(void*);
db_line* db_readline_sql(int db, db_config* conf);

#endif
